ctxpropagation

package
v0.0.0-...-7650a3f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 22, 2022 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var PropagateKey = contextKey{}

PropagateKey is the key used to store the value in the Context object

Functions

func NewContextPropagator

func NewContextPropagator() workflow.ContextPropagator

NewContextPropagator returns a context propagator that propagates a set of string key-value pairs across a workflow

Types

type Values

type Values struct {
	Key   string `json:"key"`
	Value string `json:"value"`
}

Values is a struct holding values

Directories

Path Synopsis

Jump to